@@ -1,6 +1,6 @@
 test_that("the 'get_result_names' function is working as expexted for 'clustInd_hierarch'", {
   data <- sim_model_ex1()
-  data_ind <- generate_indices(data, grid_ll = 0, grid_ul = 1)
+  data_ind <- generate_indices(data)
   res <- clustInd_hierarch(
     ind_data = data_ind,
     vars_combinations = list(c("dtaEI", "dtaMEI"), c("dtaMEI", "ddtaMEI", "d2dtaMEI")),
@@ -23,7 +23,7 @@ test_that("the 'get_result_names' function is working as expexted for 'clustInd_
 
 test_that("the 'get_result_names' function is working as expexted for 'clustInd_kmeans'", {
   data <- sim_model_ex1()
-  data_ind <- generate_indices(data, grid_ll = 0, grid_ul = 1)
+  data_ind <- generate_indices(data)
   res <- clustInd_kmeans(
     ind_data = data_ind,
     vars_combinations = list(c("dtaEI", "dtaMEI"), c("dtaMEI", "ddtaMEI", "d2dtaMEI")),
